#[unsafe(no_mangle)]pub extern "C" fn milo_fail(
parser: *mut Parser,
code: u8,
description: CStringWithLength,
)Expand description
Marks the parsing a failed, setting a error code and and error message.
#[unsafe(no_mangle)]pub extern "C" fn milo_fail(
parser: *mut Parser,
code: u8,
description: CStringWithLength,
)Marks the parsing a failed, setting a error code and and error message.