#[unsafe(no_mangle)]pub extern "C" fn milo_free_string(s: CStringWithLength)Expand description
Cleans up memory used by a string previously returned by one of the milo’s C public interface.
#[unsafe(no_mangle)]pub extern "C" fn milo_free_string(s: CStringWithLength)Cleans up memory used by a string previously returned by one of the milo’s C public interface.