Parser

Struct Parser 

#[repr(C)]
pub struct Parser {
Show 36 fields pub autodetect: bool, pub is_request: bool, pub manage_unconsumed: bool, pub continue_without_data: bool, pub is_connect: bool, pub skip_body: bool, pub max_start_line_length: usize, pub max_header_length: usize, pub context: *mut c_void, pub debug: bool, pub state: u8, pub position: usize, pub parsed: u64, pub paused: bool, pub error_code: u8, pub method: u8, pub status: u32, pub version_major: u8, pub version_minor: u8, pub content_length: u64, pub chunk_size: u64, pub remaining_content_length: u64, pub remaining_chunk_size: u64, pub has_content_length: bool, pub has_transfer_encoding: bool, pub has_chunked_transfer_encoding: bool, pub has_connection_close: bool, pub has_connection_upgrade: bool, pub has_upgrade: bool, pub has_trailers: bool, pub active_callbacks: u64, pub callbacks: ParserCallbacks, pub error_description: *const c_uchar, pub error_description_len: u16, pub unconsumed: *const c_uchar, pub unconsumed_len: usize,
}

Fields

autodetect: boolis_request: boolmanage_unconsumed: boolcontinue_without_data: boolis_connect: boolskip_body: boolmax_start_line_length: usizemax_header_length: usizecontext: *mut c_voiddebug: boolstate: u8position: usizeparsed: u64paused: boolerror_code: u8method: u8status: u32version_major: u8version_minor: u8content_length: u64chunk_size: u64remaining_content_length: u64remaining_chunk_size: u64has_content_length: boolhas_transfer_encoding: boolhas_chunked_transfer_encoding: boolhas_connection_close: boolhas_connection_upgrade: boolhas_upgrade: boolhas_trailers: boolactive_callbacks: u64callbacks: ParserCallbackserror_description: *const c_ucharerror_description_len: u16unconsumed: *const c_ucharunconsumed_len: usize

Implementations

Source

impl Parser

pub fn parse(&mut self, input: *const c_uchar, limit: usize) -> usize

Parses a slice of characters.

It returns the number of consumed characters.

Source

impl Parser

pub fn new() -> Parser

Creates a new parser

pub fn reset(&mut self, keep_parsed: bool)

Resets a parser. The second parameters specifies if to also reset the parsed counter.

The following fields are not modified:

  • position
  • context
  • autodetect
  • is_request
  • manage_unconsumed
  • continue_without_data
  • context
pub fn clear(&mut self)

Clears all values about the message in the parser.

pub fn pause(&mut self)

Pauses the parser. It will have to be resumed via resume.

pub fn resume(&mut self)

Resumes the parser.

pub fn finish(&mut self)

Marks the parser as finished. Any new data received via parse will put the parser in the error state.

pub fn fail(&mut self, code: u8, description: &str)

Marks the parsing a failed, setting a error code and and error message.

It always returns zero for internal use.

pub fn state_str(&self) -> &str

Returns the current parser’s state as string.

pub fn error_code_str(&self) -> &str

Returns the current parser’s error state as string.

pub fn error_description_str(&self) -> &str

Returns the current parser’s error description as string.